@@ -451,7 +451,7 @@ class Client:
         data = self.post(endpoint=f"/parties/v1/parties/{party_id}/request/{request_id}/decline",endpoint_type="glz")
         return data
 
-    def party_join_party(self, party_id:str) -> dict:
+    def party_join(self, party_id:str) -> dict:
         '''
         Party_PlayerJoin
         Join a party
@@ -459,7 +459,7 @@ class Client:
         data = self.post(endpoint=f"/parties/v1/players/{self.puuid}/joinparty/{party_id}",endpoint_type="glz")
         return data 
 
-    def party_leave_party(self, party_id:str) -> dict:
+    def party_leave(self, party_id:str) -> dict:
         '''
         Party_PlayerLeave
         Leave a party
